# ubotLibs Library

Core library of [ubotLibs](https://github.com/iskandar777-dar/ubotlibs), a Pyrogram And Telethon based for your userbot.


[![PyPI - Version](https://img.shields.io/pypi/v/ubotlibs?style=round)](https://pypi.org/project/ubotlibs)    
[![PyPI - Downloads](https://img.shields.io/pypi/dm/ubotlibs?label=DOWNLOADS&style=round)](https://pypi.org/project/ubotlibs)    
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://github.com/hitokizzy/ubotlibs/graphs/commit-activity)
[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/hitokizzy/ubotlibs)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)

# Installation
```bash
pip3 install ubotlibs
```


See more working plugins on [the offical repository](https://github.com/hitokizzy/ubotlibs)!

> Made with by [izzy](https://t.me/kenpatagdar).    


# License
[![License](https://www.gnu.org/graphics/agplv3-155x51.png)](LICENSE)   
ubotlibs is licensed under [GNU Affero General Public License](https://www.gnu.org/licenses/agpl-3.0.en.html) v3 or later.

